@@ -1,10 +1,10 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Exporter 'import';
-our @EXPORT = qw( portrait generate landscape transpose flip mirror reverse earthquake tsunami );
+our @EXPORT_OK = qw( portrait generate landscape transpose flip mirror reverse earthquake tsunami );
 
 use Clone;
 use HTML::AutoTag;
@@ -110,7 +110,7 @@ sub _process {
             }
 
             # -col_X
-            unless ($row == 0) {
+            unless (!$args->{matrix} and $row == 0) {
                 if (exists $args->{"-col_$col"}) {
                     if (ref($args->{"-col_$col"}) eq 'CODE') {
                         $val = $args->{"-col_$col"}->($val);
@@ -474,11 +474,19 @@ to be used as CDATA:
 
 Add colgroup tag(s) to the table. Use an AoH for multiple.
 
+  colgroup => { span => 2, style => { 'background-color' => 'orange' } }
+
+  colgroup => [ { span => 20 }, { span => 1, class => 'end' } ]
+
 =item * C<col: \@ or \%>
 
 Add col tag(s) to the table. Use an AoH for multiple. Wraps
 tags within a colgroup tag.
 
+  col => { span => 2, style => { 'background-color' => 'orange' } }
+
+  col => [ { span => 20 }, { span => 1, class => 'end' } ]
+
 =item * C<table: \%>
 
 Apply these attributes to the table tag.
